==> ouioui-0.0.16.tgz: package/es2015/controls/panel/panel.js <==
/** @jsx React.h */
import React, { Component, h } from 'preact'
import PropTypes from 'propTypes'
import { base, secondary } from '../styles'
import MdChevronLeft from '../../icons/expand-less'
import MdExpandMore from '../../icons/expand-more'

class Panel extends React.Component {

    constructor(){

        super()

        this.state = { open: true }

        this.toggleOpen = _ => this.setState({ open:!this.state.open })

    }

    render(){

        let { children, label } = this.props,
            { open } = this.state,
            Chevron = open ? MdExpandMore : MdChevronLeft

        return <div style={{ ...base, ...style }} class='oui-panel' >
            <header style={{lineHeight:'11px'}} onClick={this.toggleOpen}>
                <div style={{display:'flex'}}>
                    <label>{ label }</label>
                    <Chevron style={{marginLeft:'auto'}} />
                </div>
                { open ? <hr style={ lineStyle }/> : null }
            </header>
            { open ?
                <div>{ children }</div>
            : null }

        </div>
    }
}

Panel.defaultProps = {
    label: 'Panel'
}

var lineStyle = {
    borderWidth: '0px 0px 1px 0px',
    borderTopStyle: 'solid',
    borderRightStyle: 'solid',
    borderLeftStyle: 'solid',
    borderTopColor: secondary.color,
    borderRightColor: secondary.color,
    borderLeftColor: secondary.color,
    borderBottomColor: secondary.color
}

var style = {
    boxSizing: 'border-box',
    lineHeight: '2em',
    display: 'flex',
    flexDirection: 'column',
    width: 275,
    background: 'rgb( 250, 250, 250 )',
    borderRadius: 2,
    padding: '1em',
    margin: 0
}

export default Panel

==> ouioui-0.0.18.tgz: package/es2015/controls/panel/panel.js <==
/** @jsx React.h */
import React, { Component, h } from 'preact'
import PropTypes from 'proptypes'
import { base, secondary } from '../styles'
import MdChevronLeft from '../../icons/expand-less'
import MdExpandMore from '../../icons/expand-more'

class Panel extends React.Component {

    constructor(){

        super()

        this.state = { open: true }

        this.toggleOpen = _ => this.setState({ open:!this.state.open })

    }

    componentWillMount(){
        this.setState({ open: this.props.open })
    }

    render(){
        let { children, label } = this.props,
            { open } = this.state,
            Chevron = open ? MdExpandMore : MdChevronLeft

        return <div style={{ ...base, ...style }} class='oui-panel' >
            <header style={{lineHeight:'11px'}} onClick={this.toggleOpen}>
                <div style={{display:'flex'}}>
                    <label>{ label }</label>
                    <Chevron style={{marginLeft:'auto'}} />
                </div>
                { open ? <hr style={ lineStyle }/> : null }
            </header>
            { open ?
                <div>{ children }</div>
            : null }

        </div>
    }
}

Panel.defaultProps = {
    label: 'Panel',
    open: true
}

var lineStyle = {
    borderWidth: '0px 0px 1px 0px',
    borderTopStyle: 'solid',
    borderRightStyle: 'solid',
    borderLeftStyle: 'solid',
    borderTopColor: secondary.color,
    borderRightColor: secondary.color,
    borderLeftColor: secondary.color,
    borderBottomColor: 'rgba( 1, 1, 1, 0.05 )'
}

var style = {
    boxSizing: 'border-box',
    lineHeight: '2em',
    display: 'flex',
    flexDirection: 'column',
    width: 275,
    background: 'rgb( 250, 250, 250 )',
    borderRadius: 2,
    padding: '1em',
    margin: 0
}

export default Panel
